Re: [PATCH v2 0/2] do_compare_entry: use already-computed path
- From
Junio C Hamano <gitster@pobox.com>
- Date
- Dec 21, 2015, 23:27 UTC
- Message-ID
- <xmqqzix3e61h.fsf@gitster.mtv.corp.google.com>
- In-Reply-To
- <1450737260-15965-1-git-send-email-dturner@twopensource.com>
Thanks. Does the number still stay at 25% improvement?